<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>メインウィンドウ</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>ソフトウェア（xrandr）の明るさ</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>ハードウェア バックライト</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation>ディスプレイ</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation>&amp;中止</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="53"/>
        <location filename="../defaultlook.cpp" line="72"/>
        <location filename="../defaultlook.cpp" line="659"/>
        <location filename="../defaultlook.cpp" line="666"/>
        <location filename="../defaultlook.cpp" line="683"/>
        <location filename="../defaultlook.cpp" line="694"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;パネルのカスタマイズ&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="156"/>
        <source>Panel</source>
        <translation>パネル</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;ウィンドウの動作とショートカットの設定&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>ウィンドウマネージャー</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;デスクトップの外観をカスタマイズ&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="129"/>
        <source>Xfce Settings</source>
        <translation>Xfce の設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="311"/>
        <location filename="../defaultlook.ui" line="318"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Backup current panel configuration</source>
        <translation>現在のパネルの設定をバックアップ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="290"/>
        <source>Restore backup panel configuration</source>
        <translation>バックアップしたパネル設定を復旧</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Restore default panel</source>
        <translation>既定のパネルを復旧</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="177"/>
        <location filename="../defaultlook.ui" line="1348"/>
        <source>Affects 1st panel</source>
        <translation>第1のパネルに影響します</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="304"/>
        <source>Display panel vertically</source>
        <translation>パネルを垂直方向に表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="270"/>
        <location filename="../defaultlook.ui" line="1366"/>
        <source>Bottom</source>
        <translation>下部</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="275"/>
        <location filename="../defaultlook.ui" line="1376"/>
        <source>Top</source>
        <translation>上部</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <translation>パネルを水平方向に表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="210"/>
        <location filename="../defaultlook.ui" line="1371"/>
        <source>Left</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="215"/>
        <location filename="../defaultlook.ui" line="1381"/>
        <source>Right</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="164"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;すべてのパネルに反映されます&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ウィンドウボタン&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="333"/>
        <location filename="../defaultlook.ui" line="377"/>
        <location filename="../defaultlook.ui" line="533"/>
        <location filename="../defaultlook.ui" line="858"/>
        <location filename="../defaultlook.ui" line="865"/>
        <location filename="../defaultlook.ui" line="872"/>
        <location filename="../defaultlook.ui" line="998"/>
        <location filename="../defaultlook.ui" line="1324"/>
        <location filename="../defaultlook.ui" line="1506"/>
        <location filename="../defaultlook.ui" line="1617"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="356"/>
        <source>Theme</source>
        <translation>テーマ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="486"/>
        <source>Theme Options</source>
        <translation>テーマのオプション</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="414"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>ダークテーマを使用している場合、いくつかのウェブサイトのフィールドを修正</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="417"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox ダークテーマの tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="400"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>ダークテーマ使用時の HexChat 入力ボックスを修正</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="509"/>
        <source>Undo</source>
        <translation>元に戻す</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="407"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="469"/>
        <source>Remove User Theme Set</source>
        <translation>ユーザーテーマセットを削除</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="458"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>現在の設定をテーマセットとして保存</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="519"/>
        <location filename="../defaultlook.ui" line="560"/>
        <source>Compositor</source>
        <translation>コンポジター</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="699"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Compton-conf 設定ツールを起動</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="702"/>
        <source>Compton settings</source>
        <translation>Compton の設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="685"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce コンポジターの設定&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="688"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm の設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="667"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="672"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) コンポジター</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="677"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>compton.conf を直接テキストエディタで編集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="570"/>
        <source>Edit compton.conf</source>
        <translation>compton.conf を編集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="553"/>
        <source>Transparency and shadow options</source>
        <translation>透明度と影に関するオプション</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="620"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;VBlank モードを変更すると、画面分割の問題が軽減される場合があります。 詳細については、ヘルプを参照してください。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="623"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="631"/>
        <source>auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="636"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="641"/>
        <source>xpresent</source>
        <translation>Xresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="646"/>
        <source>off</source>
        <translation>オフ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="716"/>
        <location filename="../defaultlook.cpp" line="3356"/>
        <source>Display</source>
        <translation>ディスプレイ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="724"/>
        <source>Hardware Backlight</source>
        <translation>ハードウェア バックライト</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="731"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ディスプレイの Tweak&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="758"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>ディスプレイの XRandR tweak を選択</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="768"/>
        <source>Resolution</source>
        <translation>解像度</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="775"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;ディスプレイ毎に保存&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="778"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="785"/>
        <source>Software (xrandr) Brightness</source>
        <translation>ソフトウェア（XRandR）の明るさ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="792"/>
        <location filename="../defaultlook.ui" line="889"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="799"/>
        <source>GTK scaling</source>
        <translation>GTK のスケーリング</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="819"/>
        <source>xrandr Scaling</source>
        <translation>XRandR スケーリング</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="915"/>
        <source>Config Options</source>
        <translation>オプションの設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="923"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Thunar のカスタム右クリックアクションをシステムの既定にリセット</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>Enable single-click on desktop</source>
        <translation>デスクトップでシングルクリックを有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="937"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Thunar ファイルマネージャでシングルクリックを有効化</translation>
    </message>
    <message>
        <source>Show systray (notification area) frame</source>
        <translation type="vanished">シストレイ（通知領域）フレームを表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="951"/>
        <location filename="../defaultlook.ui" line="1466"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>パネルに全てのワークスペースのウィンドウを表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="958"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>デスクトップでの長いファイル名の短縮を無効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="965"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>ログアウトメニューでハイバネートを有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="972"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>注意: ハイバネートするには、スワップが &gt;= RAM である必要があります</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1012"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1020"/>
        <location filename="../defaultlook.ui" line="1473"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1034"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1041"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1049"/>
        <location filename="../defaultlook.ui" line="1080"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1054"/>
        <location filename="../defaultlook.ui" line="1085"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1062"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1069"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1090"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1111"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1118"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Upgrade existing menu entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1128"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1135"/>
        <location filename="../defaultlook.ui" line="1243"/>
        <location filename="../defaultlook.ui" line="1355"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1209"/>
        <source>Width</source>
        <translation>横幅</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1219"/>
        <location filename="../defaultlook.ui" line="1317"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1226"/>
        <source>Height</source>
        <translation>高さ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1236"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1334"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1459"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1452"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <source>Systray Icon Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="364"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="424"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="438"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="944"/>
        <source>Enable Desktop Zoom </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1400"/>
        <source>Default</source>
        <translation>既定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1405"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1410"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1415"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1420"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1425"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1520"/>
        <source>Other</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1597"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Lightdm（ログイン画面）をシステムの既定テーマにリセット</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1635"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>非ルートユーザーに内蔵ドライブのマウントを有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1583"/>
        <source>Enable kernel sandbox</source>
        <translation>カーネルサンドボックスの有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1576"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>デフォルトの「モード設定用」ドライバの替わりに intel ドライバを使用 (再起動が必要)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1590"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>注意: 既存の /etc/X11/xorg.conf.d/20-intel.conf はホームフォルダにバックアップされます</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1642"/>
        <source>Use tearfree amdgpu option</source>
        <translation>TearFree amdgpu オプションを使用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1628"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>注意: 既存の /etc/X11/xorg.conf.d/20-amd.conf はホームフォルダにバックアップされます。</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1535"/>
        <source>Use tearfree radeon driver option</source>
        <translation>TearFree radeon ドライバのオプションを使用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1542"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>注意: 既存の /etc/X11/xorg.conf.d/20-radeon.conf はホームフォルダにバックアップされます</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1528"/>
        <source>Password for administrative tasks:</source>
        <translation>管理業務用のパスワード：</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1562"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1649"/>
        <source>Root</source>
        <translation>ルート</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1656"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1725"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1736"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1756"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1763"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="54"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--Xfce専用のスイッチを表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>About MX Tweak</source>
        <translation>MX Tweak について</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="659"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="660"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>既定の UI テーマの変更や調整を素早く行えるアプリ</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="662"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="663"/>
        <location filename="../defaultlook.cpp" line="666"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="664"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="695"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>完了しました！ Firefox では変更を有効にするため再起動が必要な場合があります</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="886"/>
        <source>Panel settings</source>
        <translation>パネルの設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="887"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>現在のパネル設定は、ホームフォルダ (~/) 以下にある .restore という隠しフォルダにバックアップされました</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1582"/>
        <source>settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1926"/>
        <source>Choose a theme set</source>
        <translation>テーマセットを選択</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>ユーザーのテーマセットを削除</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>新しいテーマセット</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>新しいテーマセットの名前を入力</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>ウィンドウボタン</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;外観&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>ボタンラベルを表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>フラットボタンで表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>取っ手を表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>並び替え順:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>タイムスタンプ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>グループタイトルとタイムスタンプ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>ウィンドウタイトル</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>グループタイトルとウィンドウタイトル</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>なし、ドラッグアンドドロップを許可</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;振る舞い&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>ウィンドウのグループ化:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>しない</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>常時</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>中クリック時の動作:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>何もしない</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>ウィンドウを閉じる</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>最小化されたウィンドウを現在のワークスペースで元に戻す</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>ポインターがボタン上にあるときにウィンドウ枠を描画する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>マウスホイールを使用してウィンドウを切り替える</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;フィルター&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>全ワークスペースまたはビューポートのウィンドウを表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>最小化されたウィンドウのみ表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>全モニターのウィンドウを表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>ポップアップウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>移動中のウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;不透過度の設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>ウィンドウの装飾</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>ドックウインドウの下に影を表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>ポップアップウィンドウの下に影を表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>リサイズ中のウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>通常のウィンドウで影を表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;機能設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>サイクリング時にアイコンの代わりにウィンドウのプレビューを表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>フルスクリーンのオーバーレイウィンドウを直接表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>非アクティブなウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>垂直ブランクに描画を同期</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm コンポジターの設定</translation>
    </message>
</context>
</TS>
